@@ -25,7 +25,6 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
 
-#include <string.h>
 #include "jered.h"
 
 extern int resizewin;
@@ -117,7 +116,7 @@ FOR EXAMPLE IF YOUR STRING IS "YES|NO" THEN THIS FUNCTION WILL RETURN 2.
         return(nbre);
 }
 /**********************************************************************/
-static int cree_boutons(PTALERTE alerte, char *title, char *buttons)
+static int cree_boutons(PTALERTE palerte, char *title, char *buttons)
 /* Purpose:
 THIS FUNCTION CREATES A CIRCULAR LIST OF ALL THE BUTTONS OF THE ALERT
 BOX, THEN IT COMPUTES SCREEN COORDINATES TO CENTER THE ALERT BOX ON THE
@@ -167,10 +166,10 @@ SCREEN.
         /* lgmax++; */        /* 1 espace de plus a droite */
 
         lgtit = strlen(title) + 2;      /* longueur du titre + 2 espaces */
-        alerte->nbuttons = compte_boutons(txtbutt);
-        if (alerte->nbuttons)
+        palerte->nbuttons = compte_boutons(txtbutt);
+        if (palerte->nbuttons)
         {
-                lgbut = alerte->nbuttons * (lgmax + 4) + 2;
+                lgbut = palerte->nbuttons * (lgmax + 4) + 2;
 
                 lgbox = max((lgtit + 2), (lgbut + 2));
 
@@ -182,10 +181,10 @@ SCREEN.
 
                 ptb = txtbutt;                  /* pointe sur les messages des boutons */
 
-                for (i = 0; (retcode != ERROR) && (i < alerte->nbuttons); i++)
+                for (i = 0; (retcode != ERROR) && (i < palerte->nbuttons); i++)
                 {
                                 /* ajoute un bouton dans la boite d'alerte */
-                        b = ajoute_bouton(alerte);
+                        b = ajoute_bouton(palerte);
                         if (b == NULL)  /* impossible d'allouer un bouton de plus */
                                 retcode = ERROR;
                         else
@@ -193,10 +192,10 @@ SCREEN.
                                         /* si on arrive au dernier bouton, alors */
                                         /* on met a jour les pointeurs pour fermer */
                                         /* le cercle entre tous les boutons */
-                                if (i == (alerte->nbuttons - 1))
+                                if (i == (palerte->nbuttons - 1))
                                 {
-                                        b->bsuiv = alerte->bfirst;
-                                        alerte->bfirst->bprec = b;
+                                        b->bsuiv = palerte->bfirst;
+                                        palerte->bfirst->bprec = b;
                                 }
 
                                         /* calcule la chaine a associer au bouton courant */
@@ -241,16 +240,16 @@ SCREEN.
 
         if (retcode != ERROR)
         {
-                alerte->l = lgbox;
-                alerte->h = 7;
+                palerte->l = lgbox;
+                palerte->h = 7;
 
-                alerte->y = ((LINES - 1) / 2) - (alerte->h / 2);
-                if (alerte->y < 0)
-                        alerte->y = 0;
+                palerte->y = ((JEREDLINES - 1) / 2) - (palerte->h / 2);
+                if (palerte->y < 0)
+                        palerte->y = 0;
 
-                alerte->x = ((COLS / 2) - (alerte->l + (alerte->l & 1)) / 2) + 1;
-                if (alerte->x < 0)
-                        alerte->x = 0;
+                palerte->x = ((JEREDCOLS / 2) - (palerte->l + (palerte->l & 1)) / 2) + 1;
+                if (palerte->x < 0)
+                        palerte->x = 0;
 
                 ptext = (char *)malloc(lgbox + 2);
                 if (ptext != NULL)
@@ -260,7 +259,7 @@ SCREEN.
                         *(ptext + lgbox) = '\0';
                         memcpy(ptext + ((lgbox - (lgtit - 2)) >> 1), title, (lgtit - 2));
 
-                        alerte->title = ptext;
+                        palerte->title = ptext;
                 }
                 else
                         retcode = ERROR;
@@ -268,7 +267,7 @@ SCREEN.
         return(retcode);
 }
 /**********************************************************************/
-static PTBUTTON ajoute_bouton(PTALERTE alerte)
+static PTBUTTON ajoute_bouton(PTALERTE palerte)
 /* Purpose:
 THIS FUNCTION IS CALLED BY THE PREVIOUS FUNCTION. ITS PURPOSE IS TO
 SET LINKS BETWEEN BUTTONS: FOR EACH BUTTON THERE IS A POINTER TO THE
@@ -286,12 +285,12 @@ PREVIOUS BUTTON AND A POINTER TO THE NEXT BUTTON. (AJOUTE <==> ADD)
                 memset(pb, 0x0000, sizeof(BUTTON));
 
                         /* recherche ou inserer */
-                for (b = alerte->bfirst; (b != NULL) && (b->bsuiv != NULL); b = b->bsuiv) ;
+                for (b = palerte->bfirst; (b != NULL) && (b->bsuiv != NULL); b = b->bsuiv) ;
 
                 /* si on est sorti avec b = NULL, pas deja un bouton dans la boite */
                 if (b == NULL)
                 {
-                        alerte->bfirst = pb;
+                        palerte->bfirst = pb;
                 }
                 else
                 {
@@ -304,7 +303,7 @@ PREVIOUS BUTTON AND A POINTER TO THE NEXT BUTTON. (AJOUTE <==> ADD)
         return (pb);
 }
 /**********************************************************************/
-static void detruit_boutons(PTALERTE alerte)
+static void detruit_boutons(PTALERTE palerte)
 /* Purpose:
 THIS FUNCTION FREES ALL THE MEMORY ALLOCATED FOR THE CIRCULAR LIST OF
 BUTTONS, FREEING ALL MEMORY ALLOCATED FOR EACH BUTTON.
@@ -313,7 +312,7 @@ BUTTONS, FREEING ALL MEMORY ALLOCATED FOR EACH BUTTON.
         PTBUTTON b;     /* pointeur sur bouton suivant */
         PTBUTTON oldb;  /* pointeur sur bouton courant */
 
-        b = alerte->bfirst;
+        b = palerte->bfirst;
         do
         {
                 oldb = b;       /* sauve pointeur bouton courant */
@@ -324,7 +323,7 @@ BUTTONS, FREEING ALL MEMORY ALLOCATED FOR EACH BUTTON.
 
                 free(oldb);             /* libere bouton */
         }
-        while (b != alerte->bfirst);
+        while (b != palerte->bfirst);
 }
 /**********************************************************************/
 static PTALERTE cree_alerte(char *title, char *buttons)
@@ -333,32 +332,32 @@ THIS FUNCTION ALLOCATES MEMORY FOR A STRUCT _ALERTE, THEN CALLS THE
 FUNCTION TO CREATE THE CIRCULAR LIST OF BUTTONS.
  ..........................      */
 {
-        PTALERTE alerte;        /* pointeur sur la boite d'alerte creee */
+        PTALERTE palerte;        /* pointeur sur la boite d'alerte creee */
 
         if ((title == NULL) || (buttons == NULL) ||
             (! *title) || (! *buttons))
         {
-                alerte = NULL;  /* erreur dans les parametres d'appel */
+                palerte = NULL;  /* erreur dans les parametres d'appel */
         }
         else
         {
-                alerte = (PTALERTE)malloc(sizeof(ALERTE));
-                if (alerte != NULL)
+                palerte = (PTALERTE)malloc(sizeof(ALERTE));
+                if (palerte != NULL)
                 {
-                        memset(alerte, 0x0000, sizeof(ALERTE));
-                        if (cree_boutons(alerte, title, buttons) == ERROR)
+                        memset(palerte, 0x0000, sizeof(ALERTE));
+                        if (cree_boutons(palerte, title, buttons) == ERROR)
                         {
-                                free(alerte);
-                                alerte = NULL;
+                                free(palerte);
+                                palerte = NULL;
                         }
                         else
-                                alerte->firsttime = 1;
+                                palerte->firsttime = 1;
                 }
         }
-        return(alerte);
+        return(palerte);
 }
 /**********************************************************************/
-static void detruit_alerte(PTALERTE alerte)
+static void detruit_alerte(PTALERTE palerte)
 /* Purpose:
 THIS FUNCTION FREES ALL THE MEMORY ALLOCATED BY ITS COMPONENTS AND
 RESTORES THE ORIGINAL SCREEN APPEARANCE (WHAT WAS ON THE SCREEN BEFORE THE
@@ -366,26 +365,26 @@ ALERT BOX WAS DISPLAYED).
  ..........................      */
 {
         /* libere memoire allouee */
-        if (alerte != NULL)
+        if (palerte != NULL)
         {
 
-                if (alerte->video != NULL)
-                        free(alerte->video);
+                if (palerte->video != NULL)
+                        free(palerte->video);
 
-                if (alerte->sauve != NULL)
+                if (palerte->sauve != NULL)
                 {
                         /* replace l'ecran comme avant l'alerte */
-                        put_txt(alerte->x, alerte->y, alerte->x + alerte->l + 1, alerte->y + alerte->h, alerte->sauve);
+                        put_txt(palerte->x, palerte->y, palerte->x + palerte->l + 1, palerte->y + palerte->h, palerte->sauve);
 
                         /* libere memoire de la copie de l'ecran */
-                        free(alerte->sauve);
+                        free(palerte->sauve);
                 }
-                if (alerte->title != NULL)
-                        free(alerte->title);
+                if (palerte->title != NULL)
+                        free(palerte->title);
 
-                detruit_boutons(alerte);
+                detruit_boutons(palerte);
 
-                free(alerte);
+                free(palerte);
         }
 }
 /**********************************************************************/
@@ -408,7 +407,7 @@ STRING.
         return(mem);
 }
 /**********************************************************************/
-static void dessine_bouton(PTALERTE alerte, PTBUTTON bouton)
+static void dessine_bouton(PTALERTE palerte, PTBUTTON bouton)
 /* Purpose:
 THIS FUNCTION DRAWS A BUTTON INTO THE MEMORY, PREPARING THE BUFFER TO
 BE OUTPUTTED ON THE SCREEN.
@@ -446,10 +445,10 @@ BE OUTPUTTED ON THE SCREEN.
                 first = 0;
         }
 
-        ptl = ptw = (chtype *)alerte->video + bouton->xr + (alerte->l * bouton->yr);
+        ptl = ptw = (chtype *)palerte->video + bouton->xr + (palerte->l * bouton->yr);
 
         coulf = couleur[COULEUR_ALERTE1];
-        if (bouton == alerte->bselected)
+        if (bouton == palerte->bselected)
         {
                 ptc = cadrage;          /* cadre double */
                 coulx = couleur[COULEUR_ALERTE2];      /* couleur du texte du bouton selectionne */
@@ -470,7 +469,7 @@ BE OUTPUTTED ON THE SCREEN.
 
         *ptw++ = (*++ptc | coulf);
 
-        ptl = ptw = ptl + alerte->l;
+        ptl = ptw = ptl + palerte->l;
 
         *ptw++ = (*++ptc | coulf);
 
@@ -481,7 +480,7 @@ BE OUTPUTTED ON THE SCREEN.
 
         *ptw++ = (*ptc | coulf);
 
-        ptw = ptl + alerte->l;
+        ptw = ptl + palerte->l;
 
         *ptw++ = (*++ptc | coulf);
 
@@ -491,7 +490,7 @@ BE OUTPUTTED ON THE SCREEN.
         *ptw++ = (*++ptc | coulf);
 }
 /**********************************************************************/
-static PTBUTTON dessine_alerte(PTALERTE alerte, PTBUTTON newbutton, \
+static PTBUTTON dessine_alerte(PTALERTE palerte, PTBUTTON newbutton, \
  PTBUTTON oldbutton)
 /* Purpose:
 THIS FUNCTION DOES THE SAME THING AS THE PREVIOUS FUNCTION BUT FOR THE
@@ -515,13 +514,13 @@ BUFFER IS OUTPUTTED ON THE SCREEN BY THE FUNCTION put_txt().
         chtype cm;              /* pour montant */
 
         coulf = couleur[COULEUR_ALERTE1];
-        if (alerte->firsttime)
+        if (palerte->firsttime)
         {
-                alerte->firsttime = 0;
+                palerte->firsttime = 0;
 
                         /* calcul de la taille necessaire */
-                sizelig = ((alerte->l + 2) * sizeof(chtype));
-                sizemem = (sizelig + 2) * (alerte->h + 1);
+                sizelig = ((palerte->l + 2) * sizeof(chtype));
+                sizemem = (sizelig + 2) * (palerte->h + 1);
 
                         /* allocation de la memoire pour sauver l'ecran */
                 memsauve = (chtype *)malloc(sizemem + 2);
@@ -537,23 +536,23 @@ BUFFER IS OUTPUTTED ON THE SCREEN BY THE FUNCTION put_txt().
                 }
 
                         /* met a jour les pointeurs dans la boite */
-                alerte->sauve = memsauve;
-                alerte->video = memvideo;
+                palerte->sauve = memsauve;
+                palerte->video = memvideo;
 
                         /* sauve l'ecran avant l'ouverture de l'alerte */
-                get_txt(alerte->x, alerte->y, alerte->x + alerte->l + 1, alerte->y + alerte->h, alerte->sauve);
+                get_txt(palerte->x, palerte->y, palerte->x + palerte->l + 1, palerte->y + palerte->h, palerte->sauve);
 
                 memset(space, ' ', 78);
                 space[78] = '\0';
-                space[alerte->l - 2] = '\0';
+                space[palerte->l - 2] = '\0';
 
                 cb = hmd();
-                lg = alerte->l - 2;
+                lg = palerte->l - 2;
 
                 cm = mgd();
 
                 ptw = memvideo;
-                for (j = 0; j < alerte->h; j++)
+                for (j = 0; j < palerte->h; j++)
                 {
                         switch (j)
                         {
@@ -593,7 +592,7 @@ BUFFER IS OUTPUTTED ON THE SCREEN BY THE FUNCTION put_txt().
 
                                 case 1:
                                         *ptw++ = (cm | coulf);
-                                        ptw = carac_attrib((unsigned char *)alerte->title, ptw, coulf);
+                                        ptw = carac_attrib((unsigned char *)palerte->title, ptw, coulf);
                                         *ptw++ = (cm | coulf);
 
                                         break;
@@ -608,16 +607,16 @@ BUFFER IS OUTPUTTED ON THE SCREEN BY THE FUNCTION put_txt().
                 }
 
                         /* on dessine chacun des boutons de la boite pour le premier passage */
-                b = alerte->bfirst;
+                b = palerte->bfirst;
                 do
                 {
-                        dessine_bouton(alerte, b);
+                        dessine_bouton(palerte, b);
                         b = b->bsuiv;
                 }
-                while (b != alerte->bfirst);
+                while (b != palerte->bfirst);
 
                         /* affiche la boite d'alerte */
-                put_txt(alerte->x, alerte->y, alerte->x + alerte->l - 1, alerte->y + alerte->h - 1, alerte->video);
+                put_txt(palerte->x, palerte->y, palerte->x + palerte->l - 1, palerte->y + palerte->h - 1, palerte->video);
         }
 
                 /* on redessine maintenant l'ancien bouton et le nouveau */
@@ -625,19 +624,19 @@ BUFFER IS OUTPUTTED ON THE SCREEN BY THE FUNCTION put_txt().
                 /* sinon ca vient d'etre fait plus haut */
         if (oldbutton != newbutton)
         {
-                alerte->bselected = newbutton;
+                palerte->bselected = newbutton;
 
-                dessine_bouton(alerte, oldbutton);
-                dessine_bouton(alerte, newbutton);
+                dessine_bouton(palerte, oldbutton);
+                dessine_bouton(palerte, newbutton);
 
-                put_txt(alerte->x, alerte->y + alerte->bfirst->yr,
-                        alerte->x + alerte->l - 1, alerte->y + alerte->bfirst->yr + 2,
-                        alerte->video + (alerte->l * alerte->bfirst->yr));
+                put_txt(palerte->x, palerte->y + palerte->bfirst->yr,
+                        palerte->x + palerte->l - 1, palerte->y + palerte->bfirst->yr + 2,
+                        palerte->video + (palerte->l * palerte->bfirst->yr));
         }
         return(newbutton);
 }
 /**********************************************************************/
-static int lire_alerte(PTALERTE alerte)
+static int lire_alerte(PTALERTE palerte)
 /* Purpose:
 THIS FUNCTION FIRST DRAWS THE ALERT BOX, THEN READ KEYS FROM KEYBOARD
 AND ACTS ACCORDING TO WHAT IS TYPED. FOR EXAMPLE IF YOU TYPED LEFT ARROW
@@ -652,7 +651,7 @@ IS RE-DRAWN IN SELECTED MODE.
 
         retcode = ERROR;
 
-        dessine_alerte(alerte, alerte->bselected, alerte->bselected);
+        dessine_alerte(palerte, palerte->bselected, palerte->bselected);
 
         quitte = 0;
         while (! quitte)
@@ -668,14 +667,14 @@ IS RE-DRAWN IN SELECTED MODE.
 
                         case KEY_RETURN:
                         case KEY_LINEFEED:
-                                for (retcode = 1, b = alerte->bfirst; b != alerte->bselected; retcode++, b = b->bsuiv);
+                                for (retcode = 1, b = palerte->bfirst; b != palerte->bselected; retcode++, b = b->bsuiv);
                                 quitte = 1;
                                 break;
 
                         case KEY_RIGHT:
                         case KEY_ESPACE:
                         case KEY_TAB:
-                                if (dessine_alerte(alerte, alerte->bselected->bsuiv, alerte->bselected) == NULL)
+                                if (dessine_alerte(palerte, palerte->bselected->bsuiv, palerte->bselected) == NULL)
                                 {
                                         retcode = ERROR;
                                         quitte = 1;
@@ -685,7 +684,7 @@ IS RE-DRAWN IN SELECTED MODE.
                         case KEY_LEFT:
                         case Shift_TAB:
                         case KEY_BTAB:
-                                if (dessine_alerte(alerte, alerte->bselected->bprec, alerte->bselected) == NULL)
+                                if (dessine_alerte(palerte, palerte->bselected->bprec, palerte->bselected) == NULL)
                                 {
                                         retcode = ERROR;
                                         quitte = 1;
@@ -723,7 +722,7 @@ FOR EXAMPLE:    userchoice = alerte(2, "Choose what you want"
                                 /* counter */
         PTBUTTON b;             /* pointeur sur le bouton recherche */
                                 /* pointer to the button requested */
-        PTALERTE alerte;        /* pointeur sur la boite d'alerte */
+        PTALERTE palerte;   /* pointeur sur la boite d'alerte */
                                 /* pointer to the box of the alert */
                                 
         inputmode = DIALOGMODE;                                        
@@ -731,18 +730,18 @@ FOR EXAMPLE:    userchoice = alerte(2, "Choose what you want"
         eteint_curseur();       /* eteint le curseur */
                                 /* switches off the cursor */
 
-        alerte = cree_alerte(title, buttons);
-        if (alerte != NULL)
+        palerte = cree_alerte(title, buttons);
+        if (palerte != NULL)
         {
                         /* recherche le bouton pre-selecte */
                         /* request the button selected */
-                for (i = 1, b = alerte->bfirst; i < selected; i++)
+                for (i = 1, b = palerte->bfirst; i < selected; i++)
                         b = b->bsuiv;
-                alerte->bselected = b;
+                palerte->bselected = b;
 
-                retcode = lire_alerte(alerte);
+                retcode = lire_alerte(palerte);
 
-                detruit_alerte(alerte);
+                detruit_alerte(palerte);
         }
         else
                 retcode = ERROR;
