@@ -382,6 +382,8 @@ void test_config(char *line)
 			language = GERMAN;
 		else if ((! strncasecmp(line + 9, "RUSSIAN", 7)) || (! strncasecmp(line + 9, "RUSSIAN", 7)))
 			language = RUSSIAN;
+		else if ((! strncasecmp(line + 9, "SPANISH", 7)) || (! strncasecmp(line + 9, "SPANISH", 7)))
+			language = SPANISH;
 		else
 			language = ENGLISH;
 
