@@ -47,17 +47,23 @@ extern char vmacroname[66];
 
 extern FILELIST *debut_liste;
 
+void getscreensize(void);
 /**********************************************************************/
 int function_redraw(FICHIER *fichier, char *buffer, int position)
 {
         int cursor;
+        int i;
+        
         
         /* save current cursor's value */
         cursor = allume_curseur(0);
         allume_curseur(cursor);
         
-        termine_ecran();
-        debute_ecran();
+        endwin();
+        clr_scr();
+        
+        getscreensize();
+        
         set_jered_colors();
         
         if (fichier == NULL)
@@ -71,6 +77,11 @@ int function_redraw(FICHIER *fichier, char *buffer, int position)
         affiche_ecran(fichier, 0, NULL);
         
         set_refresh(OFF);
+        if (fichier->ligne >= JEREDLINES)
+        {
+                for (i = 0; i <= (fichier->ligne - JEREDLINES + 1); i++)
+                        remonter_ligne(fichier);
+        }        
         affiche_status_line(fichier, fichier->colonne + fichier->premier_caractere + 1);
         affiche_help_line();
         set_refresh(ON);
@@ -102,7 +113,7 @@ int function_genhelp(FICHIER *fichier, char *buffer, int position)
                 {
                         msg = get_keymap(i);
                         if (msg != NULL)
-                                fprintf(fout, "%s: %s\n", key_name(i), msg);
+                                fprintf(fout, "%s: %s\n", jkey_name(i), msg);
                 }
                 
                 /* then print all ESC keys */
@@ -110,7 +121,7 @@ int function_genhelp(FICHIER *fichier, char *buffer, int position)
                 {
                         msg = get_keymap(i + (KEY_MAX + 1));
                         if (msg != NULL)
-                                fprintf(fout, "%s: %s\n", key_name(i + (KEY_MAX + 1)), msg);
+                                fprintf(fout, "%s: %s\n", jkey_name(i + (KEY_MAX + 1)), msg);
                 }
                 fclose(fout);   /* we close the file */
                 
@@ -336,7 +347,7 @@ int function_home(FICHIER *fichier, char *buffer, int position)
 int function_end(FICHIER *fichier, char *buffer, int position)
 {
         droite(fichier, buffer, 0, 1);
-        if (fichier->colonne + fichier->premier_caractere > (COLS - 1))
+        if (fichier->colonne + fichier->premier_caractere > (JEREDCOLS - 1))
                 affiche_ecran(fichier, fichier->premier_caractere, fichier->courante);
         return(0);
 }
@@ -352,7 +363,7 @@ int function_left(FICHIER *fichier, char *buffer, int position)
 int function_right(FICHIER *fichier, char *buffer, int position)
 {
         droite(fichier, buffer, 0, 0);
-        if (fichier->colonne + fichier->premier_caractere > (COLS - 1))
+        if (fichier->colonne + fichier->premier_caractere > (JEREDCOLS - 1))
                 affiche_ecran(fichier, fichier->premier_caractere, fichier->courante);
         return(0);
 }
@@ -400,7 +411,7 @@ int function_tab(FICHIER *fichier, char *buffer, int pos)
                 while (nbspaces--)
                 {
                         droite(fichier, buffer, 1, 0);
-                        if (fichier->colonne + fichier->premier_caractere > (COLS - 1))
+                        if (fichier->colonne + fichier->premier_caractere > (JEREDCOLS - 1))
                                 affiche_ecran(fichier, fichier->premier_caractere, fichier->courante);
                 }
         }
